# -*- coding: utf-8 -*-
#
# ServiceReference to MovieName  - Converter
#
# Coded by dre (c) 2014
# Support: www.dreambox-tools.info
# E-Mail: dre@dreambox-tools.info
#
# This Converter is open source but it is NOT free software.
#
# This Converter may only be distributed to and executed on hardware which
# is licensed by Dream Multimedia GmbH.
# In other words:
# It's NOT allowed to distribute any parts of this Converter or its source code in ANY way
# to hardware which is NOT licensed by Dream Multimedia GmbH.
# It's NOT allowed to execute this Converter and its source code or even parts of it in ANY way
# on hardware which is NOT licensed by Dream Multimedia GmbH.
#
# If you want to use or modify the code or parts of it,
# you have to keep MY license and inform me about the modifications by mail.
#

from Components.Converter.Converter import Converter
from Components.Element import cached
from enigma import eServiceCenter, eServiceReference, iPlayableServicePtr
from re import compile
from Components.config import config

class RefToMovieName(Converter, object):
	def __init__(self, type):
		Converter.__init__(self, type)
		#pattern: show.SnnEnn.filetype / show - SnnEnn - episode.filetype
		self.tvseries = compile('(.*?)[\s\.-]*[S|s][0-9]+[E|e][0-9]+(.*?)')
		#pattern: SnnEnn.show.filetype / SnnEnn - show.filetype
		self.tvseriesalt = compile('^[S|s][0-9]+[E|e][0-9]+[\s\.\-]*(.*?)\.[ts|m2ts|mp3|wav|ogg|jpg|jpeg|jpe|png|bmp|mpg|mpeg|mkv|mp4|mov|divx|avi|mp2|m4a|flac|ifo|vob|iso|sh|flv|3gp|mod|wmv]')
		#pattern: show - season (episodenr/total episodes) (no filetype!)
		self.tvseriestotal= compile('(.*?)[\s-][\s](.*?)\([0-9]+\/[0-9]+\)')
		#pattern: show - (nxn) episode (videodb)
		self.tvseriesvideodb = compile('(.*?)[\s\.-]*\([0-9]+x[0-9]+\)(.*?)')
		#pattern: movies
		self.movietitle = compile('(.*\w)\.[ts|m2ts|mp3|wav|ogg|jpg|jpeg|jpe|png|bmp|mpg|mpeg|mkv|mp4|mov|divx|avi|mp2|m4a|flac|ifo|vob|iso|sh|flv|3gp|mod|wmv]')
		#pattern: movie (year).filetype
		self.movieyear = compile('(.*\w) \([0-9]+\)\.[ts|m2ts|mp3|wav|ogg|jpg|jpeg|jpe|png|bmp|mpg|mpeg|mkv|mp4|mov|divx|avi|mp2|m4a|flac|ifo|vob|iso|sh|flv|3gp|mod|wmv]')

	@cached
	def getText(self):
		ref = self.source.service
		if isinstance(ref, iPlayableServicePtr):
			info = ref and ref.info()
			ref = None
			if info:
				match = ""
				moviename = ref and info.getName(ref)
				if moviename is None:
					moviename = info.getName()
					if self.tvseriesvideodb.match(moviename) is not None:
						match = self.tvseriesvideodb.match(moviename).groups()[0].rstrip()
					elif self.tvseriestotal.match(moviename) is not None: 
						match = self.tvseriestotal.match(moviename).groups()[0].rstrip()
					elif self.tvseriesalt.match(moviename) is not None:
						match = self.tvseriesalt.match(moviename).groups()[0].rstrip()
					elif self.tvseries.match(moviename) is not None:
						match = self.tvseries.match(moviename).groups()[0].rstrip()
					elif self.movietitle.match(moviename) is not None:
						match = self.movietitle.match(moviename).groups()[0].rstrip()
					elif self.movieyear.match(moviename) is not None:
						match = self.movieyear.match(moviename).groups()[0].rstrip()							
					if match == "":
						return moviename.replace(" ","_").replace(".","_").replace("/","_")
					else:
						return match.replace(" ","_").replace(".","_").replace("/","_")
		if ref is not None:
			if ref.flags & (eServiceReference.flagDirectory):
				return "folder"
			info = eServiceCenter.getInstance().info(ref)
			if info:
				match = ""
				moviename = info.getName(ref)
				if self.tvseriesvideodb.match(moviename) is not None:
					match = self.tvseriesvideodb.match(moviename).groups()[0].rstrip()
				elif self.tvseriestotal.match(moviename) is not None:
					match = self.tvseriestotal.match(moviename).groups()[0].rstrip()
				elif self.tvseriesalt.match(moviename) is not None:
					match = self.tvseriesalt.match(moviename).groups()[0].rstrip()	
				elif self.tvseries.match(moviename) is not None:
					match = self.tvseries.match(moviename).groups()[0].rstrip()
				elif self.movietitle.match(moviename) is not None:
					return self.movietitle.match(moviename).groups()[0].rstrip()
				elif self.movieyear.match(moviename) is not None:
					match = self.movieyear.match(moviename).groups()[0].rstrip()						
				if match == "":
					return moviename.replace(" ","_").replace(".","_").replace("/","_")
				else:
					return match.replace(" ","_").replace(".","_").replace("/","_")
		return ""
		
	text = property(getText)

	def changed(self, what):
		Converter.changed(self, what)	